(function ($, Drupal) {
  Drupal.behaviors.contentOverview = {
    attach: function (context, settings) {
      once("content-overview", ".content-overview", context).forEach(
        function (element) {
          var $toc = $(element);

          // Check if the toggle button and container are already created
          if ($toc.closest(".toc-container").length === 0) {
            var $container = $('<div class="toc-container"></div>');
            var $toggleButton = $(
              '<button class="toc-toggle-button">Show Content Overview</button>'
            );

            // Insert container and toggle button
            $toc.before($container);
            $container.append($toggleButton).append($toc);
            $toc.hide();

            // Toggle functionality
            $toggleButton.on("click", function () {
              $toc.slideToggle(400, function () {
                var isVisible = $toc.is(":visible");
                $toggleButton.text(
                  isVisible
                    ? "Hide Content Overview"
                    : "Show Content Overview"
                );
              });
            });
          }
        }
      );

      // Ensure smooth scrolling is applied only once to each link
      once("toc-link", ".content-overview a", context).forEach(function (
        link
      ) {
        $(link).on("click", function (event) {
          event.preventDefault();
          var titleText = $(this).data("title");

          // Find the first heading element containing this title text
          var $target = $("h1, h2, h3, h4, h5, h6")
            .filter(function () {
              return $(this).text().trim() === titleText;
            })
            .first();

          if ($target.length) {
            // Calculate the target position
            var targetOffset = $target.offset().top;
            var headerHeight = $(".fixed-header").outerHeight() || 0;

            // Animate scroll with adjustment for header
            $("html, body").animate(
              {
                scrollTop: targetOffset - headerHeight,
              },
              600
            );
          } else {
            console.warn("Target not found for title: " + titleText);
          }
        });
      });
    },
  };
})(jQuery, Drupal);
