<?php

namespace Drupal\content_overview\Plugin\Block;

use Drupal\Core\Block\BlockBase;

/**
 * Provides a 'Table of Contents' Block.
 *
 * @Block(
 *   id = "content_overview_block",
 *   admin_label = @Translation("Content Overview Block")
 * )
 */
class ContentOverviewBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $toc = '';

    // Check if we are on a node page.
    $route_match = \Drupal::routeMatch();
    $node = $route_match->getParameter('node');

    if ($node && $node->hasField('body')) {
      // Generate the TOC from the body field.
      $toc = $this->generateContentOverview($node->body->value);
    }

    return [
      '#theme' => 'content_overview',
      '#toc' => $toc,
      '#attached' => [
        'library' => [
          'content_overview/content_overview',
        ],
      ],
      '#cache' => [
        'contexts' => ['route'],
      ],
    ];
  }

  /**
   * Generates a table of contents based on the headings in the content.
   *
   * @param string $content
   *   The HTML content to scan for headings.
   *
   * @return string
   *   The table of contents as an HTML unordered list, or an empty string if no
   *   headings are found.
   */
  protected function generateContentOverview($content) {
    $toc = '';
    $heading_pattern = '/<h([1-6])>(.*?)<\/h\1>/i';
    preg_match_all($heading_pattern, $content, $matches, PREG_SET_ORDER);

    if (!empty($matches)) {
      $toc .= '<ul class="content-overview">';
      foreach ($matches as $heading) {
        $level = $heading[1];
        $title = strip_tags($heading[2]);

        // Generate a safe anchor name for the TOC link (not an ID)
        $toc .= '<li class="toc-level-' . $level . '"><a href="#" class="toc-link" data-title="' . htmlspecialchars($title) . '">' . $title . '</a></li>';
      }
      $toc .= '</ul>';
    }

    return $toc;
  }

}
